@@ -1,13 +1,17 @@
+"""
+Main entry points for the package.
+"""
+
 import sys
 
-def main():                 # Will be used as entry-point in setup.cfg
+def main():                 # Will be used as entry-point in pyproject.toml
     """
     Main function of the package.
 
     Read arguments from `sys.argv[1:]`.
 
-    .. Note:: Will be used as `pyyc` entry-point in :ref:`setup.cfg`,
-              and as the main script (`python -m pyyc`).
+    .. Note:: Will be used as `pyyc` entry-point in :ref:`pyproject.toml`,
+              and in the `__main__` block (`python -m pyyc`).
     """
 
     print("Command line arguments:", sys.argv[1:])
@@ -19,7 +23,8 @@ def main_addition():
 
     Read arguments from `sys.argv[1:]`.
 
-    .. Note:: Will be used as `pyyc_addition` entry-point in :ref:`setup.cfg`.
+    .. Note:: Will be used as `pyyc_addition` entry-point
+              in :ref:`pyproject.toml`.
     """
 
     try:
